from datetime import datetime, timedelta
from gwlogging import logger

#Power jobs
J_P_Gumstix = 1  # Turn on gumstix
J_P_GumstixPcon = 2  # Turn on gumstix and process power mask
J_P_PCON = 3  # turn on pcon for exec time then turn off
J_P_SPCON = 3  # turn on spcon for exec time then turn off
J_P_PCONON = 5  # turn on pcon
J_P_SPCONON = 5  # turn on spcon
J_P_PCONOFF = 7  # turn off pcon
J_P_SPCONOFF = 7  # turn off spcon
J_P_Gumstix_OFF = 9  # turn off gumstix
J_P_GumstixPCON_OFF = 10

#Sensor jobs
J_S_SENS = 21  # read sensors
J_S_SENSSPCON = 22  # turn on power mask & sense
J_S_CURRENT = 23  # read the current sensors
J_S_SENSSPCON_LOW = 24  # turn output low read sensor and set high again


class MspJob:
    """Describes a job from the msp"""

    def __init__(self, number, jobType, exec_time, interval,
                power_time, power_mask, sensor_mask,
                status=None):
        self.number = number
        self.jobType = jobType
        self.exec_time = exec_time
        self.interval = interval
        self.power_time = power_time
        self.power_mask = power_mask
        self.sensor_mask = sensor_mask
        self.status = status

    def __str__(self):
        s = "Job Number: %s\n" % self.number
        s += "Job Type: %s\n" % self.jobType
        s += "Exec Time: %s\n" % self.exec_time
        s += "Interval: %s\n" % self.interval
        s += "Power Time: %s\n" % self.power_time
        s += "Power Mask %s \n" % self.power_mask
        s += "Sensor Mask %s\n" % self.sensor_mask
        s += "Status %s \n" % self.status
        return s


def parse(s):
    """Parses a list of strings as returned by the msp and
    returns an array containing all the jobs"""
    ret = []
    if not s:
        logger.warn("Empty job table nothing to parse")
    else:
        for i in s:
            arr = str.split(i, "\t")
            if len(arr) >= 8:
                time = datetime.utcfromtimestamp(float(arr[2]))
                delta = timedelta(seconds=float(arr[3]))
                power_time = timedelta(seconds=float(arr[4]))
                d = MspJob(arr[0], arr[1], time, delta, power_time,
                     arr[5], arr[6], arr[7])
                ret.append(d)
            else:
                raise Exception("Not enough elements in array")
    return ret
