"""
    Provides an interface to the open image grabber software
"""

import subprocess

from gwlogging import logger, gw_stdout, gw_stderr
from variables import IMAGE_GRABBER, IMAGE_CONVERTER

GRABBER = IMAGE_GRABBER
CONVERTER = IMAGE_CONVERTER


def list_devices():
    """
        Lists the devices detected by the grabber
    """
    raw = subprocess.check_output(GRABBER)
    devices = {}
    for line in raw.split("\n"):
        if not line == "":
            arr = line.split("\t")
            devices[arr[0]] = arr[2]
    return devices


def capture(device_id, filename, width=640, height=480):
    """
        Captures from the specified to the file at the given res
    """
    logger.debug("Catpure Device:%d File:%s Width:%d Height:%d" % (
        device_id, filename, width, height))
    proc = subprocess.Popen(args="%s %d %s %d %d" % (GRABBER, device_id,
        filename, width, height), shell=True, stdout=gw_stdout,
        stderr=gw_stderr)
    ret = proc.wait()
    return ret == 0


def convert(iput, oput, quality=80):
    """
        Converts from a ppm to a jpeg
    """
    logger.debug("Convert Input:%s Output:%s Quality:%d" %
        (iput, oput, quality))
    proc = subprocess.Popen(args="%s -quality %s -optimize %s > %s" %
        (CONVERTER, quality, iput, oput), shell=True, stdout=gw_stdout,
        stderr=gw_stderr)
    ret = proc.wait()
    return ret == 0
