# contains all the variables needed for glacsweb 2011 deployment to enable
# easy modification

import datetime

#from gwlogging import *
from serverdetails import ServerDetails 
from odict import odict 


BASE = 'base'
REF = 'ref'
FARM = 'farm'
CAM = 'camera'

# FILE LOCATIONS

# Base dir -- data, queued and archive all relative to this:
BASE_DIR = "/glacsweb"
# Data directory
DATA_DIR = "/data"
# Data queued for scp'ing
QUEUED_DIR = "/queued"
# Data that has been scp'ed
ARCHIVE_DIR = "/archive"
#Contains the binaries for various dump routines
BIN_FOLDER = "/root/bin"

# Special file location to download to
SPECIAL_FILE = "special"

# Path to access the power files
POWER_UPLOAD = "/power/upload.php"
POWER_DOWNLOAD = "/power/download.php"

# Forces the python to not turn off at the end of the run until the file is
#deleted
STAY_AWAKE_FILE = BASE_DIR + "/stayawake"
# Hold execution of gwstation
WAIT_FILE = BASE_DIR + "/wait"
# Keep comms up if exists
COMMS_STAY_AWAKE_FILE = BASE_DIR + "/comms_stayawake"

#Stores the previous power state
BATV_FILE = BASE_DIR + "/batv_status"
#Stores the timestamp of the last time the python sucessfully executed
INFO_FILE = BASE_DIR + "/info"
#Stores details of number of times booted
BOOT_FILE = BASE_DIR + "/boot"
#Temp file that the downloaded over-ride power level is stored in
OVERIDE_FILE = BASE_DIR + "/overide_state"
#File that all data downloaded from the MSP is dumped into
MSP_DATA_FILE = "%s/%s/msp-data" % (BASE_DIR, DATA_DIR)


#TIMING VARIABLES

# Number of seconds that it's worth powering off for
WORTH_POWER_OFF = datetime.timedelta(seconds=120)
# Number of seconds it takes to boot
BOOT_TIME = datetime.timedelta(seconds=60)
# Number of seconds to make sure we stay awake for
MIN_AWAKE_TIME = datetime.timedelta(seconds=40)
# When this script should run
RUN_HOUR = 11
RUN_MINUTE = 59
RUN_SECOND = 00
# Stay connected for this number * the schedule state seconds:
COMMS_CONNECT_TIME = 60
# Give up if we don't get a GPRS connection after this long:
COMMS_TRY_TIME = datetime.timedelta(minutes=1)
MAX_PROBE_DOWNLOAD_TIME = datetime.timedelta(minutes=15, seconds=30)
MAX_PROBE_PING_REPEATS = 10
MAX_GPS_DOWNLOAD_TIME = datetime.timedelta(hours=3)
MAX_WEATHER_DOWNLOAD_TIME = datetime.timedelta(hours=1)
MAX_GEOPHONE_DOWNLOAD_TIME = datetime.timedelta(minutes=30)
MAX_CAMERA_TIME = datetime.timedelta(seconds=90)
MAX_SPECIAL_TIME = datetime.timedelta(minutes=45)
#MSP vs Gum drift allowable
MSP_DRIFT = datetime.timedelta(seconds=60)


#RTC to use
RTC = "/dev/rtc1"

#NETWORK VARIABLES

REF_NETWORK_INTERFACE = "eth1"
BASE_NETWORK_INTERFACE = "wlan0"
WPA_CONTROL_PATH = "/var/run/wpa_supplicant"
#Reverse ssh ports
BASE_REVERSE_PORT = 6666
REF_REVERSE_PORT = 6667
FARM_REVERSE_PORT = 6668
CAM_REVERSE_PORT = 6669
#The upper bound to count as a small file
SMALL_FILE_SIZE = 1 * 1024 * 1024
#Location of lock file to block ppp connection
PPP_PID_FILE = "/var/run/ppp-gw-gprs.pid"
# A Dictionary of SSH servers to try to connect to
sshServers = odict()
cloud = ServerDetails(
        "incoming.glacsweb.info", "glacsweb",
        "/root/.ssh/glacsweb_key",
        "/home/glacsweb/www/iceland/incoming", "/iceland")
env = ServerDetails(
        "data.glacsweb.info", None, None, None,
        "/iceland", True)
sshServers['cloud'] = cloud
sshServers['env'] = env
sshServers['login'] = ServerDetails(
            "login.ecs.soton.ac.uk", "km",
            "/home/glacsweb/.ssh/id_dsa",
            "/home/km/glacsweb/", None)
# A Dictionary of SSH servers to try to connect to
webServers = odict()
webServers['cloud'] = cloud
webServers['env'] = env


#MSP COMMS

#Number of attempts to make at a failed message to the MSP430
MSP_RETRY_ATTEMPTS = 5
#The serial port used for the msp430
MSP_SERIAL_PORT = "/dev/ttyO5"
#The baud rate to use for comms
MSP_BAUD_RATE = 38400


#PROBE STUFF
PROBE_DUMP_PATH = "/root/probe/probe_job.py"
PROBE_RETRY_ATTEMPTS = 20
PROBE_SPECIAL_FILE = "probe_special"
PROBE_GOT_FILE = "/glacsweb/probe-got"
# Plain text containing a list of the files that have already been fetched


#GPRS Stuff

#Path to binary
GWGSM = BIN_FOLDER + "/gwgsm"
#Serial port to use
GPRS_PORT = "/dev/gprs-serial"
#Baud rate
GPRS_BAUD = 57600


#GPS Stuff
#Path to binary
GWGPS = BIN_FOLDER + "/gwgps"
#Path to dump script
GPS_DUMP_PATH = "/root/code/gps-dump.py"
#Path to dump temporary file list
GPS_LIST_PATH = "/tmp/gps_ls"
#baud rate to use
GPS_BAUD_RATE = 57600
#Serial port
GPS_PORT = "/dev/gps-serial"


#Weather Stuff
#path to binary
GWWEATHER = BIN_FOLDER + "/gwweather"
#baud rate to use
WEATHER_BAUD_RATE = 19200
#serial port
WEATHER_SERIAL_PORT = "/dev/weather-serial"

WEATHER_DUMP_PATH = "/root/code/weather-dump.py"


#Geophone dump stuff
GEOPHONE_DUMP_PATH = "/root/probe/geophone_job.py"
GEOPHONE_BAUD_RATE = 38400
GEOPHONE_SERIAL_PORT = "/dev/geophone-serial"
GEOPHONE_DATA_FILE = BASE_DIR + DATA_DIR + "/geophone.txt"
GEOPHONE_SPECIAL_FILE = "geophone_special"

#Camera stuff
CAMERA_CONF_FILE = "/root/code/cameras.conf"
BORECAM_CONF_FILE = "/root/code/borecam.conf"
IMAGE_GRAB_PATH = "/root/code/grab-picture.py"
IMAGE_GRABBER = BIN_FOLDER + "/grabber"
IMAGE_CONVERTER = "/usr/bin/cjpeg" 
