#!/usr/bin/env python

# Retrieves all files from the GPS

# Note you must turn on the GPS unit before running this script


from os import remove

import gps
from variables import GPS_LIST_PATH, BASE_DIR, DATA_DIR
from gwlogging import logger 

# Stop GPS logging
logger.info("Stopping GPS logging")
ret = gps.stop()
if ret == 1 or ret < 0 or ret >= 126:
    logger.error("Failed to stop logging")
    exit(1)

# Get the list of log files
logger.info("Getting list of GPS log files")
ret = gps.list(GPS_LIST_PATH)
if ret == 1 or ret < 0 or ret >= 126:
    logger.error("Failed to receive list of GPS log files.")
    exit(1)

# Get each log file - delete from GPS unit if successful
gps_logs = open(GPS_LIST_PATH, "r")
try:
    for log in gps_logs:
        log = log.rstrip('\n')
        if not(log == ""):
            logger.debug("Fetching GPS log file: %s" % log)
            ret = gps.get("%s%s/%s" % (BASE_DIR, DATA_DIR, log), log)
            if ret == 1 or ret < 0 or ret >= 126:
                logger.error("Failed to receive GPS log file: %s" % log)
            elif ret == 0:
                logger.info("Received GPS log file: %s" % log)
                logger.debug("Deleting GPS log file: %s" % log)
                ret = gps.delete(log)
                if ret == 1 or ret < 0:
                    logger.error("Failed to delete GPS log file: %s" % log)
                elif ret == 0:
                    logger.debug("Deleted GPS log file: %s" % log)
finally:
    gps_logs.close()
    remove(GPS_LIST_PATH)
