#!/usr/bin/env python
"""
    Loads a config file and grabs images from all the specified devices
"""
import camera
from gwlogging import logger
from gwfileutils import  load_config
from GwErrors import GwConfigError

from os import remove
from sys import argv

TMPFILE = "/tmp/cam.ppm"

def grab_pictures(conf_file):
    try:
        conf = load_config(conf_file)
    except GwConfigError:
        logger.critical("Failed to load config")
        exit(1)

    for cam in conf:
        logger.info("capturing %s" % cam)
        if camera.capture(cam.device, TMPFILE, cam.xres, cam.yres):
            logger.debug("Capture sucessful now converting")
            if camera.convert(TMPFILE, cam.filename):
                logger.info("Capture and conversion successful")
            else:
                logger.error("Conversion failed")
            remove(TMPFILE)
            logger.debug("%s deleted" % TMPFILE)
        else:
            logger.error("Catpure failed")


if __name__ == "__main__":
    if len(argv) != 2:
        conffile = "/root/code/cameras.conf"
    else:
        conffile = argv[1]
    grab_pictures(conffile)
