from datetime import datetime
from subprocess import Popen
from os import kill
from signal import SIGTERM
from time import sleep
from iceCape import GPS, WEATHER
from variables import MAX_GPS_DOWNLOAD_TIME, GPS_DUMP_PATH, WEATHER_DUMP_PATH, \
    MAX_WEATHER_DOWNLOAD_TIME, MAX_PROBE_DOWNLOAD_TIME, PROBE_DUMP_PATH, \
    IMAGE_GRAB_PATH, MAX_CAMERA_TIME, CAMERA_CONF_FILE 
from gwlogging import logger, gw_stderr, gw_stdout


def get_gps_logs(gum):
    """Gets the data from the GPS device
    expects the serial port to exist """
    start = datetime.utcnow()
    finish = start + MAX_GPS_DOWNLOAD_TIME
    logger.info("Powering on GPS unit")
    gum.turn_on_sensor_output(GPS)
    gps_dump = Popen(args="python " + GPS_DUMP_PATH,
                               shell=True, stdout=gw_stdout,
                               stderr=gw_stderr)
    while gps_dump.poll() is None:
        if datetime.utcnow() > finish:
            logger.error("Forcing GPS dump stop")
            kill(gps_dump.pid, SIGTERM)
            gps_dump.wait()
        else:
            sleep(10)
    finish = datetime.utcnow()
    logger.debug("Powering off GPS unit")
    gum.turn_off_sensor_output(GPS)
    logger.info("Time taken for gps dump %s" % (str(finish - start)))


def get_weather_data(gum):
    """Gets the data from the weather device
    expects the serial port to exist """
    start = datetime.utcnow()
    finish = start + MAX_WEATHER_DOWNLOAD_TIME
    previous_power_state = bool(gum.output_status() & WEATHER)
    logger.info("Weather already powered: %r" % previous_power_state)
    if not previous_power_state:
        logger.info("Powering on weather unit")
        gum.turn_on_sensor_output(WEATHER)
    weather_dump = Popen(args="python " + WEATHER_DUMP_PATH,
                               shell=True, stdout=gw_stdout,
                               stderr=gw_stderr)
    while weather_dump.poll() is None:
        if datetime.utcnow() > finish:
            logger.error("Forcing stop of weather dump")
            kill(weather_dump.pid, SIGTERM)
            weather_dump.wait()
        else:
            sleep(10)
    finish = datetime.utcnow()
    if not previous_power_state:
        logger.debug("Powering off weather unit")
        gum.turn_off_sensor_output(WEATHER)
    logger.info("Time taken for weather dump %s" % (str(finish - start)))


def get_probe_data():
    """Get probes data - well duh"""
    logger.info("Starting probe download")
    start = datetime.utcnow()
    finish = start + MAX_PROBE_DOWNLOAD_TIME
    probe_dump = Popen(args="python " + PROBE_DUMP_PATH,
                                    shell=True, stdout=gw_stdout,
                                    stderr=gw_stderr)
    while probe_dump.poll() is None:
        if datetime.utcnow() > finish:
            logger.error("Forcing stop of Probe dump")
            kill(probe_dump.pid, SIGTERM)
            probe_dump.wait()
        else:
            sleep(10)
    finish = datetime.utcnow()
    logger.info("Time taken for probe dump %s " % (str(finish - start)))


def get_camera_image(conf_file=CAMERA_CONF_FILE):
    """
        Gets data from the webcams attached - also works with the deep borecam
    """
    logger.debug("Starting image acquisition")
    start = datetime.utcnow()
    finish = start + MAX_CAMERA_TIME
    take_image = Popen(args="%s %s" %
                                    (IMAGE_GRAB_PATH, conf_file),
                                    shell=True, stdout=gw_stdout,
                                    stderr=gw_stderr)

    while take_image.poll() is None:
        if datetime.utcnow() > finish:
            logger.error("Forcing abort of image capture")
            kill(take_image.pid, SIGTERM)
            take_image.wait()
        else:
            sleep(10)
    finish = datetime.utcnow()
    logger.info("Time taken for image capture %s " % (str(finish - start)))
