from datetime import datetime, date
from time import mktime
from os import system 
from subprocess import check_output

from variables import RTC, MSP_DRIFT
from gwlogging import logger


def next_time(n, interval):
    # n is the time set in start_time
    # interval is the interval between jobs
    # We want to set the next_time to be some offset in the future.
    # if days takes you over next, set start time to be +#days+start_time
    now = datetime.utcnow()
    new = datetime.combine(date(2000, 01, 01), n)
    while new < now:
        new += interval
    logger.debug("new time:%s" % new)
    return new


def timedelta2seconds(delta):
    if delta is None:
        return None
    else:
        return (delta.days * 60 * 60 * 24) + delta.seconds


def set_system_time(t):
    system('date -s +%s' % t.__str__())
    #TODO add error checking


def set_hwclock(fname=RTC):
    r = system('hwclock -f %s --utc  --set --date "%s"' % (
        fname, datetime.utcnow()))
    if r != 0:
        logger.error("Something went wrong setting the HW clock")


def get_hwclock(fname=RTC):
    system('hwclock -f %s -s' % fname)


def read_hwclock(fname=RTC):
    t = check_output(["hwclock", "-f" + fname, "-r"])
    return datetime.strptime(t[0:t.index("  ")],
        "%a %d %b %Y %H:%M:%S %Z")


def check_time(m):
    """ Returns false if the MSP is only slightly wrong"""
    if not check_time_coarse(m):
        #MSP is badly wrong
        return False
    else:
        logger.info("time check with coarse boundary")
        g = datetime.utcnow()
        if g == m:
            logger.info("Remote time exactly the same as local")
            return True
        elif m > g:
            logger.warn("Remote slightly fast:%s" % (m - g))
            return True
        elif m < g:
            logger.warn("Remote slightly slow:%s" % (g - m))
            return True
        else:
            logger.error("Not sure how I got here so assuming wrong")
            return False


def check_time_coarse(m):
    """Returns false if the MSP is very wrong"""
    g = datetime.utcnow()
    logger.info("Checking course time. Local: %s, Remote: %s" % (g, m))
    if g == m:
        logger.info("Remote time exactly the same as Local")
        return True
    elif m > g:
        if m - g > MSP_DRIFT:
            logger.error("Remotevery fast:%s" % (m - g))
            return False
    elif m < g:
        if g - m > MSP_DRIFT:
            logger.warn("Remote very slow:%s" % (g - m))
            return False
    else:
        logger.error("Not sure how I got here so assuming wrong")
        return False
    return True


def time2seconds(time):
    """converts a time to the number of seconds past midnight making it
        suitable for use in scheduling"""
    if time is None:
        return None
    else:
        return time.hour * 60 * 60 + time.minute * 60 + time.second


def totimestamp(d):
    """Convert a datetime into a timestamp.
    Gets rid of daylight saving adjustments"""
    if d is None:
        return None
    else:
        t = list(d.timetuple())
        t[-1] = 0
        return int(mktime(tuple(t)))
